bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 6. Aventiure
___________________________________________________ #### Auentv wie sich Gunther gein Islande hin ze Prvnh' bereite
| ### Ez> was ein kuniginne gesezzen vber se ### ir geliche enheine man wesse ninder me ### div was vnmazen schoene vil michel was ir chraft ### si schoz mit snellen degenen vmbe minne den schaft ### Den stein den warf si verre darnach si wite spranch ### swer an si wenden wolde sinen gedanch ### driv spil mvserr an behaben der frowen wol geborn ### gebrast im an dem einen er het daz hovbet sin verlorn
###### 331 | ### Des het div kuniginne vnmazen vil getan ### do gevriesch ez bi dem Rine ein ritter wolgetan ### der wande sine sinne an daz herliche wip ### darvmbe mvsin helede sit verliesen den lip
###### 332 | ### Do si eines tages sazen der kunic un– sine man ### manigen ende si ez mazen beidiv wider vn– dan ### welhe ir herre mohte zeinem wibe nemen ### div in ze frowen tohte vn– ovch dem lande mohte zemen
| ### Do sprach der vogt von Rine ich wil nider an den se ### hin ze Prvenhilde swie ez mir erge ### dvrch ir vnmazen schoene so wage ich minen lip ### den wil ich verliesen sine werde min wip
###### 334 | ### Daz wil ich widerraten sprach do Sivrit ### ia hat div kuniginne so vreisliche site ### swer vmb ir minne wirbet daz ez im hohe stat ### des mvget ir der reise haben wærlichen rat
###### 335 | ### Do sprach der kunich Gvnther nie geborn wart ein wip ### so starch un– ovch so chvne ine wolde wol ir lip ### in strite betwingen mit min selbes hant ### swiget sprach do <Sifrit> iv ist ir ellen vnbekant
###### 336 | ### Vn– wærn iwer viere dine kunden niht genesn ### von ir vil <grimmen> zorne ir lat den willen wesn ### daz rat ieh iv mit triwen welt ir niht ligen tot ### sone lat ivch nach ir minne niht ze sere wesn not
| ### So wil ich iv [13v]wol raten sprach do Hagene ### ir bitet Sifride mit iv ze tragene ### die vil starchen sorge daz ist nv min rat ### side im daz ist so kundich wiez vmbe Privnhilde stat
###### 338 | ### Er sprach wiltv mir helfen degen Sifrit ### die minnekliche erwerben tvostv des ich dih bite ### vn– wirt mir zeinem trvote daz herliche wip ### ich wil durch dinen willen wagen ere vn– lip
###### 339 | ### Des antwrte Sifrit swie mir min dinch da chvom ### gistv mir din swester so bin ich dir frvom ### die schonen Chriemhilde ein kuniginne her ### ine ger deheiner miete nach minen arebeiten mer
###### 340 | ### Daz lobe ich sprach do Gvnther Sivrit an dine hant ### vn– kvomt div schone Prvnhilt her in dizze lant ### so wil ich dir ze wibe die mine swester gebn ### so mahtv mit der schonen immer vroliche lebn
###### 341 | ### Des sworen si do eide die rechen vil her ### des wart ir arebeiten verre deste mer ### ê si die <wolgetanen> brehten an den Rin ### des mvsen die vil chvnen starche sorgende sin
| ### Von wilden getwergen han ich gehoeret sagen ### si sin in holn bergen vn– daz si ze scherme tragen ### einez heizet tarnkappen von wnderlicher art ### swerz hat an sime libe der sol vil gar wol sin bewart
###### 343 | ### vor slegen vn– vor stichen in mvge ovch niemen sehen ### swenner si darinne beide horn vn– spehen ### mag er nach sinem willen daz in doch niemen siht ### er si ovch verre stercher als uns div auenture giht
###### 344 | ### Mit im fvrt Sifrit die tarnkappen an ### die der helt vil kune nnit sorgen gewan ### ab einem getwerge daz hiez Albrich ### sich bereiten zv der verte die degn chune vn– rich
###### 345 | ### Also der starche Sifrit die tarnkappen trvch ### so het er dar inne chrefte genvoch ### zwelf ander manne sterche als uns ist geseit ### er gewan mit grozen listen die vil <herlichen> meit
###### 346 | ### Ovch was div selbe tarnhvot also getan ### daz dar inne worhte ein ieslicher man ### swaz er selbe wolde daz in doch niemen sach ### so gewan er Prvonhilde da von im leide sit geschach
| ### Dv solt mir sagen Sifrit e unser vart erge ### daz wir mit vollen eren chomen an den se ### svln wir iht ritter fvren in Prvnh' lant ### <zwei> tusint degene die werdent schiere besant
###### 348 | ### Swie vil wir volches fvrten sprach do Sifrit ### ez pfliget div kuniginne so eyslicher site ### die mvsen alle ersterben von ir vbervot ### ich wil ivch baz bewisen degen chvne vnde gvot
###### 349 | ### Wir svln in rechen wise varn zetal den Rin ### die wil ich iv nennen die daz svln sin ### zvo vns zwein noch zwene vn– niemen me ### so erwerben wir die frowen swiez vns dar nach erge
###### 350 | ### Der gesellen sit ir einer der ander sol ich wesn ### Hagene si der dritte wir mvgen wol genesn ### Danehwart si der vierde der vil chvene man ### vns endurfen ander tvsint mit strite nimmer bestan
| ### Div mære ich [14r]wiste gerne sprach der kunic do ### e daz wir hinne schieden des wære ich harte vro ### waz wir kleider solden vor <Prvnhilde> tragen ### div uns da wol gezæmen daz svlt ir mir bi zite sagen
###### 352 | ### Wat die aller besten die ieman bevant ### die treit man zallen citen in Prvnh' lant ### des suln wir richiv chleider vor der frowen tragen ### daz wirs iht habn scande so man div mære hore sagen
###### 353 | ### Do sprach der degn gvter so wil ich selbe gan ### zv miner lieben mvter ob ich erwerben chan ### daz uns ir schone mægede helfen <prvven> chleit ### die wir tragen mit eren fvr die herlichen meit
###### 354 | ### Do sprach von Tronege Hagene mit herlichen siten ### wes welt ir iwer mvter solher dienste biten ### lat <iwer> swester horen wes wir habn mvot ### si ist so chvnst riche daz div chleider werdent gvt
| ### Do enbot er siner swester daz er si wolde sehn ### vn– ovch der herre Sifrit ê daz daz was geschehn ### do hete sich div schone ze wnsche wol gechleit ### daz si sie sehn wolden des was si vro vn– ovch gemeit
###### 356 | ### Do was ovch ir gesinde gezieret als ir gezam ### die fvrsten chomen beide do si daz vernam ### do stvnt si von dem sidele mit zvhten si do gie ### do si den gast vil edelen vn– ovch ir bruder enpfie
###### 357 | ### Wilechomen si min bruder vn– der geselle sin ### div mære wist ich gerne so sprach daz magedin ### was ir werben woldet sit ir ze hofe gat ### daz lat mich beide horen wiez iv hochgemvten stat
###### 358 | ### Do sprach der chunic riche frowe ich wilz iv sagn ### wir mvzin michel sorgen bi hohem mvte tragn ### wir wellen hobeschen riten verre in vremdiv lant ### wir solden zv der reise haben zierlich gewant
| ### Nv sizzet lieber brvoder sprach daz kuniges kint ### lat mich div mære hoeren wer die frowen sint ### der ir da gere mir minnen in ander fuorsten lant ### die vz erwelten beide nam div frowe bi der hant
###### 360 | ### Do gie si mit den degenen da si selbe saz ### matraz div richen ir svlt gelovben daz ### lagen allenthalben an dem vlezze nider ### si heten bi den frowen gvot kurzwile sider
###### 361 | ### Vil lieplicher bliche vn– minneklichez sehn ### des mohte da in beiden harte vil <gescehen> ### er trvch si imme hercen si was im so der lip ### er erwarp mit starchem dienste daz si doch sider wart sin wip
###### 362 | ### Do sprach der kunic Gunther vil edel swester min ### ane dine helfe sone kundez niht gesin ### wir wellen zvercewilen in Prvnhilde lant ### da bedorften wir ze tragene vor frowen herlich gewant
| ### Do sprach div kuniginne vil lieber brvder min ### swaz der minen helfe daran kan gesin ### des bringe ich ivch wol innen daz ich iv bin bereit ### versagt iv ander iemen daz wære Chriemh' leit
###### 364 | ### Irn svlt mich ritter edele niht sorgende biten ### ia svlt ir mir gebieten mit herlichen siten ### swaz so iv gevalle des bin ich bereit ### vn– tvon ez willekliche sprach div herliche meit
###### 365 | ### Wir wellen liebiv swester tragen gvt gewant ### daz sol helfen prveuen iwer wiziv hant ### des volziehen iwer mægede daz [14v]ez vns rehte stat ### <wande> ich dirre verte han deheiner slahte rat
###### 366 | ### Do sprach div iuncfrowe ine wil iv niht versagn ### ich han selbe siden nu heizet uns her tragen ### gestein vf den schilden so machen wir div kleit ### daz ir si traget mit eren fvr die <herlichen> meit
| ### Wer sint die gesellen sprach div kunigin ### die mit iv gekleidet ze hofe svln sin ### daz bin ich vn– Sifrit vni zwene miner man ### Danchwart vn– Hagene die svln mit vns ze hofe gan
###### 368 | ### Nv merchet liebiv swester rehte waz wir sagen ### daz wir vier gesellen ze vier tagen tragen ### ie drier hande kleider vn– also gvot gewant ### daz wir ane scande rvemen Prunh' lant
###### 369 | ### Daz lobte si den rechen die herren schieden dan ### do hiez ir ivncfrowen drizzech meide gan ### vz ir kemenaten Chriemh' div chunigin ### die vil werch spæhen ze chvnste heten grozen sin
###### 370 | ### Aller hande siden vn– wiz so der sne ### von Zazamanc dem lande grvn also der kle ### dar in si leiten steine des wrden gvtiv kleit ### selbe sneit si Chriemhilt div vil minnekliche meit
###### 371 | ### Von vremder vische hvten bezoch wolgetan ### ze sehn werden lvten swaz man der gewan ### die dache man mit siden golt dar in getragen ### man mohte michel wnder von der liehten wæte sagen
###### 372 | ### Von Marroch vz dem lande vn– ovch von Libyan ### die aller besten siden die ie mer gewan ### deheines kuniges chunne der heten si genvoch ### div frowe lie wol schinen daz si in holden willen trvoch
###### 373 | ### Wande sis zer hovereise heten so gegert ### die hêrminen vedere dvhten si vnwert ### pfelle dar obe lagen swarz alsam der chol ### daz noch snellen degenen stvnde in hochgeciten wol
###### 374 | ### Vz arabischem golde vil gesteines schein ### der frowen vnmvze div enwas niht klein ### inre sehs wochen bereiten si div kleit ### do was ovch ir gewæfen den gvten degenen bereit
| ### Do si bereitet waren do was in vf den Rin ### bereitet vlizekliche ein starchez schiffelin ### daz si tragen solde vol nider vf <den> se ### den schoenen <iuncfrowen> tet ir arebeiten we
###### 376 | ### Do sagt man den rechen in wærn nv bereit ### div si da fveren solden ir zierlichen kleit ### also die helde gerten daz was nv getan ### done wolden si niht langer bi dem Rine bestan
###### 377 | ### Nach den hergesellen wart balde do gesant ### ob si schowen wolden niwez ir gewant ### ob iz den helden wære ze rehte kvrz vn– lanch ### des sageten si den frowen von schulden grozlichen danch
###### 378 | ### Fvr alle die si chomen die mvsen in des iehen ### daz si ze der werlde hæten schoners niht gesehn ### des mohten si sie gerne da ze hove tragen ### von bezzer helde wæte chunde iv nieman niht gesagn
| ### Vlizekliche danchen wart da niht verdeit ### vrlovbes von in gerten die rechen vil gemeit ### in ritterlichen zvhten die herren taten daz [15r] ### des wrden liehtiv ovgen weinens trvebe vn– naz
###### 380 | ### Si sprach vil lieber brvder ir mohtet noch bestan ### vn– wrbet ander frowen daz hiez ich wol getan ### da iv so sere enwage stvnde niht der lip ### ir mvgt hie naher vinden ein also hochgeborn wip
###### 381 | ### Ich wen in saget ir herce daz inn da von geschach ### si weinten al gemeine swaz ieman drvmbe sprach ### ir golt in vor den brusten wart von træhenen sal ### die vielen in genote von den ovgen hin zetal
###### 382 | ### Si sprach herre Sivrit lat iv bevolhen sin ### vf triwe vn– vf genade den lieben brvder min ### daz im iht gewerre in Prvnhilde lant ### daz lobt ir der herre mit gvtem willen in die hant
| ### Do sprach der degen chvene ob mir min lip bestat ### so svlt ir aller sorgen frowe haben rat ### ich bringen <iv> gesunden her wider an den Rin ### daz habt vf mime libe im <neich> daz schone magedin
###### 384 | ### Ir golt roten schilde die trvg man vf den sant ### vn– braht in zv dem schiffe allez ir gewant ### ir ross hiez man in ziehen si wolden varn dan ### do wart von schonen frowen vil michel weinen getan
###### 385 | ### Do stvnden in den venstern div minneklichen kint ### ir sciff mit dem segele daz rvort ein hoher wint ### die stolzen hergesellen vlvzzen zetal den Rin ### do sprach der kunich Gunther wer sol nv schiffmeister sin
###### 386 | ### Do sprach der starche Sivrit ich kan ivch vf der flvot ### hinnen wol gefveren daz wizzet helede gvot ### die rehte wazzerstrazen die sint mir wol bekant ### mit frevden si do schiedenn vz der Buregonden lant
###### 387 | ### Der kunich von Niderlanden eine schalten genam ### von stade begunde schieben der helt vil lobesam ### Gunther der chuene selbe ein rvoder trvoc ### si hvben sich von lande vn– warn vrolich genvoch
| ### Si fvrten riche spise dar zv den besten win ### den man inder chunde vinden vmben Rin ### Danchwart Hagenen brvoder der saz vn– zoch ### an eime starchen rvoder er trvch den mvot vnmazen hoch
###### 389 | ### Ir vil starchen segelseil wrden in gestraht ### si fvren manige mile ê daz ez wrde naht ### mit frevden si do chomen vol nider an den se ### ir starchez arebeiten tet sit den hochgemvten we
###### 390 | ### Inre tage zwelven so wir hoern sagen ### heten si die winde verre dan getragen ### gein Isensteine in Prvnh' lant ### daz het von Tronege Hagene ê vil selten bekant

<<< Übersicht <<< vorige Seite nächste Seite >>>